-module(start_system).
-export([start/0, start_ai_game/0, stop/0]).

%% 启动整个系统
start() ->
    io:format("Starting cardSrv system...~n"),
    % 确保应用程序已启动
    case application:ensure_all_started(cardSrv) of
        {ok, _} ->
            io:format("System started successfully!~n"),
            {ok, started};
        {error, Reason} ->
            io:format("Failed to start system: ~p~n", [Reason]),
            {error, Reason}
    end.

%% 启动一个全AI玩家的游戏
start_ai_game() ->
    io:format("Creating an AI-only game...~n"),
    % 确保系统已启动
    case start() of
        {ok, _} ->
            % 创建AI游戏
            case game_manager:create_ai_game() of
                {ok, GameId} ->
                    io:format("AI game created successfully with ID: ~p~n", [GameId]),
                    {ok, GameId};
                {error, Reason} ->
                    io:format("Failed to create AI game: ~p~n", [Reason]),
                    {error, Reason}
            end;
        {error, Reason} ->
            {error, Reason}
    end.

%% 停止系统
stop() ->
    io:format("Stopping cardSrv system...~n"),
    application:stop(cardSrv),
    io:format("System stopped.~n"),
    ok.